A biserial correlation is a correlation between dichotomous-ordinal and
continuous variables.
Usage
BiserialCorrelation(i, t)
Arguments
- i
i is a dichotomous-ordinal variable (0/1). x and y can also be the other way around.
- t
t is a continuous variable. x and y can also be the other way around.
Value
The biserial correlation coefficient between the two variables.