The conditional correct response rate (CCRR) represents the ratio of the students who passed Item C (consequent item) to those who passed Item A (antecedent item). This function is applicable only to binary response data.
Usage
CCRR(U, na = NULL, Z = NULL, w = NULL)
# Default S3 method
CCRR(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'binary'
CCRR(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'nominal'
CCRR(U, na = NULL, Z = NULL, w = NULL)Arguments
- U
Either an object of class "exametrika" or raw data. When raw data is given, it is converted to the exametrika class with the
dataFormatfunction.- na
Values to be treated as missing values.
- Z
Missing indicator matrix of type matrix or data.frame. Values of 1 indicate observed responses, while 0 indicates missing data.
- w
Item weight vector specifying the relative importance of each item.
Value
A matrix of conditional correct response rates with exametrika class. Each element (i,j) represents the probability of correctly answering item j given that item i was answered correctly.