The dimensionality is the number of components the test is measuring.
Usage
Dimensionality(U, na = NULL, Z = NULL, w = NULL)
# Default S3 method
Dimensionality(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'binary'
Dimensionality(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'rated'
Dimensionality(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'ordinal'
Dimensionality(U, na = NULL, Z = NULL, w = NULL)Arguments
- U
Either an object of class "exametrika" or raw data. When raw data is given, it is converted to the exametrika class with the
dataFormatfunction.- na
Values to be treated as missing values.
- Z
Missing indicator matrix of type matrix or data.frame. Values of 1 indicate observed responses, while 0 indicates missing data.
- w
Item weight vector specifying the relative importance of each item.