The joint correct response rate (JCRR) is the rate of students who passed both items. This function is applicable only to binary response data. For non-binary data, it will automatically redirect to the JSR function with an appropriate message.
Usage
JCRR(U, na = NULL, Z = NULL, w = NULL)
# Default S3 method
JCRR(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'binary'
JCRR(U, na = NULL, Z = NULL, w = NULL)
# S3 method for class 'nominal'
JCRR(U, na = NULL, Z = NULL, w = NULL)Arguments
- U
Either an object of class "exametrika" or raw data. When raw data is given, it is converted to the exametrika class with the
dataFormatfunction.- na
Values to be treated as missing values.
- Z
Missing indicator matrix of type matrix or data.frame. Values of 1 indicate observed responses, while 0 indicates missing data.
- w
Item weight vector specifying the relative importance of each item.
Value
A matrix of joint correct response rates with exametrika class. Each element (i,j) represents the proportion of students who correctly answered both items i and j.