Calculates the probability of selecting each category given a latent trait value and item parameters.
Examples
if (FALSE) { # \dontrun{
# Example for an item with 3 categories
a <- 1.5
b <- c(-1.0, 1.0)
theta <- 0
grm_prob(theta, a, b)
} # }
Calculates the probability of selecting each category given a latent trait value and item parameters.
if (FALSE) { # \dontrun{
# Example for an item with 3 categories
a <- 1.5
b <- c(-1.0, 1.0)
theta <- 0
grm_prob(theta, a, b)
} # }