Learn R Programming

exametrika (version 1.8.1)

response_type_error: Generate Error Message for Invalid Response Type

Description

Internal function to generate standardized error messages when a function is called with an incompatible response type.

Usage

response_type_error(response_type, fun_name)

Value

Never returns; always stops with an error message

Arguments

response_type

character. One of "binary", "rated", "ordinal", or "nominal"

fun_name

character. Name of the calling function