Calculates the value of the Item Information Function for the Graded Response Model.
Details
The information is Samejima's (1969) item information for the GRM,
$$I(\theta) = \sum_{k=1}^{K} \frac{[P_k'(\theta)]^2}{P_k(\theta)},$$
where \(P_k(\theta) = P_{k-1}^*(\theta) - P_k^*(\theta)\) is the
category response probability, \(P_k^*(\theta)\) is the cumulative
(boundary) probability with \(P_0^* = 1\) and \(P_K^* = 0\), and
\(P_k^{*\prime}(\theta) = a P_k^*(\theta) [1 - P_k^*(\theta)]\).
The logistic metric of the estimation routine is used as is (no
1.702 scaling constant), so the information is consistent with the
parameters returned by GRM and with the posterior
standard deviations (PSD).